<?php
/**
 * 2007-2016 PrestaShop
 *
 * Thirty Bees is an extension to the PrestaShop e-commerce software developed by PrestaShop SA
 * Copyright (C) 2017 Thirty Bees
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@thirtybees.com so we can send you a copy immediately.
 *
 * @author    Thirty Bees <modules@thirtybees.com>
 * @package   getfreeshipping
 * 
 * -- Original Header --
 * Get Free Shipping PrestaShop module.
 *
 * @package   gmgetfreeshipping
 * @author    Dariusz Tryba (contact@greenmousestudio.com)
 * @copyright Copyright (c) Green Mouse Studio (http://www.greenmousestudio.com)
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

if (!defined('_TB_VERSION_')) {
    exit;
}

class GetFreeShipping extends Module
{

    public function __construct()
    {
        $this->name = 'getfreeshipping';
        $this->tab = 'front_office_features';
        $this->version = '1.0.0';
        $this->author = 'thirty bees';
        $this->need_instance = 0;

        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Get free shipping');
        $this->description = $this->l('Display Spend another X to get free shipping message in cart');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
    }

    public function install()
    {
        if (Shop::isFeatureActive()) Shop::setContext(Shop::CONTEXT_ALL);

        if (!parent::install() ||
            !$this->registerHook('shoppingCart')
        ) return false;

        return true;
    }

    public function hookShoppingCart($params)
    {
        $free_shipping = Configuration::get('PS_SHIPPING_FREE_PRICE');
        if ($free_shipping) {
            $free_shipping_price = Tools::convertPrice($free_shipping);
            $cart = $this->context->cart;
            $total_without_shipping = $cart->getOrderTotal(true, Cart::BOTH_WITHOUT_SHIPPING);
            $remaining_to_spend = $free_shipping_price - $total_without_shipping;
            $this->context->smarty->assign(
                array(
                    'free_shipping_price' => $free_shipping_price,
                    'total_without_shipping' => $total_without_shipping,
                    'remaining_to_spend' => $remaining_to_spend
                )
            );
            return $this->display(__FILE__, 'getfreeshipping.tpl');
        }
        return false;
    }
}
